==> igniteui-react-core-16.16.1.tgz: package/esm2015/lib/WebPaneDragOverEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebPaneDragOverEventArgsDescription } from "./WebPaneDragOverEventArgsDescription";
/**
 * @hidden
 */
export let WebPaneDragOverEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebPaneDragOverEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (WebPaneDragOverEventArgsDescriptionMetadata.a == null) {
                WebPaneDragOverEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebPaneDragOverEventArgsDescriptionMetadata.c(WebPaneDragOverEventArgsDescriptionMetadata.a);
            }
            if (a.g(WebPaneDragOverEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.s(WebPaneDragOverEventArgsDescriptionMetadata.a);
            WebPaneDragOverEventArgsDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:PaneDragOverEventArgs");
            a.item("Detail", "ExportedType:WebPaneDragOverEventArgs");
        }
        static d(a) {
            WebPaneDragOverEventArgsDescriptionMetadata.b(a);
            a.u("WebPaneDragOverEventArgs", () => new WebPaneDragOverEventArgsDescription());
            a.t("WebPaneDragOverEventArgs", WebPaneDragOverEventArgsDescriptionMetadata.a);
        }
    }
    WebPaneDragOverEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(WebPaneDragOverEventArgsDescriptionMetadata, 'WebPaneDragOverEventArgsDescriptionMetadata');
    WebPaneDragOverEventArgsDescriptionMetadata.a = null;
    return WebPaneDragOverEventArgsDescriptionMetadata;
})();

==> igniteui-react-core-18.0.0.tgz: package/esm2015/lib/WebPaneDragOverEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebDockManagerPaneDescriptionMetadata } from "./WebDockManagerPaneDescriptionMetadata";
import { WebPaneDragActionDescriptionMetadata } from "./WebPaneDragActionDescriptionMetadata";
import { WebPaneDragOverEventArgsDescription } from "./WebPaneDragOverEventArgsDescription";
/**
 * @hidden
 */
export let WebPaneDragOverEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebPaneDragOverEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (WebPaneDragOverEventArgsDescriptionMetadata.a == null) {
                WebPaneDragOverEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebPaneDragOverEventArgsDescriptionMetadata.c(WebPaneDragOverEventArgsDescriptionMetadata.a);
            }
            if (a.g(WebPaneDragOverEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.s(WebPaneDragOverEventArgsDescriptionMetadata.a);
            WebDockManagerPaneDescriptionMetadata.d(a);
            WebPaneDragActionDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:PaneDragOverEventArgs");
            a.item("SourcePane", "ExportedType:WebDockManagerPane");
            a.item("Panes", "Collection:WebContentPane:ContentPaneCollection:WebContentPane");
            a.item("Action", "ExportedType:WebPaneDragAction");
            a.item("IsValid", "Boolean");
        }
        static d(a) {
            WebPaneDragOverEventArgsDescriptionMetadata.b(a);
            a.u("WebPaneDragOverEventArgs", () => new WebPaneDragOverEventArgsDescription());
            a.t("WebPaneDragOverEventArgs", WebPaneDragOverEventArgsDescriptionMetadata.a);
        }
    }
    WebPaneDragOverEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(WebPaneDragOverEventArgsDescriptionMetadata, 'WebPaneDragOverEventArgsDescriptionMetadata');
    WebPaneDragOverEventArgsDescriptionMetadata.a = null;
    return WebPaneDragOverEventArgsDescriptionMetadata;
})();
